==> glibc-2.16.0.tar.bz2: glibc-2.16.0/libio/iofopen64.c <==
/* Copyright (C) 1993,1997,1999,2000,2002,2012 Free Software Foundation, Inc.
   This file is part of the GNU C Library.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with the GNU C Library; if not, see
   <http://www.gnu.org/licenses/>.

   As a special exception, if you link the code in this file with
   files compiled with a GNU compiler to produce an executable,
   that does not cause the resulting executable to be covered by
   the GNU Lesser General Public License.  This exception does not
   however invalidate any other reasons why the executable file
   might be covered by the GNU Lesser General Public License.
   This exception applies to code released by its copyright holders
   in files containing the exception.  */

#include "libioP.h"
#include <stdlib.h>

_IO_FILE *
_IO_fopen64 (filename, mode)
     const char *filename;
     const char *mode;
{
#ifdef _G_OPEN64
  return __fopen_internal (filename, mode, 0);
#else
  __set_errno (ENOSYS);
  return NULL;
#endif
}

#ifdef weak_alias
weak_alias (_IO_fopen64, fopen64)
#endif

==> glibc-2.18.tar.bz2: glibc-2.18/libio/iofopen64.c <==
/* Copyright (C) 1993-2013 Free Software Foundation, Inc.
   This file is part of the GNU C Library.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with the GNU C Library; if not, see
   <http://www.gnu.org/licenses/>.

   As a special exception, if you link the code in this file with
   files compiled with a GNU compiler to produce an executable,
   that does not cause the resulting executable to be covered by
   the GNU Lesser General Public License.  This exception does not
   however invalidate any other reasons why the executable file
   might be covered by the GNU Lesser General Public License.
   This exception applies to code released by its copyright holders
   in files containing the exception.  */

#include "libioP.h"
#include <fcntl.h>
#include <stdlib.h>

/* iofopen.c defines _IO_fopen64/fopen64 as aliases if O_LARGEFILE==0.  */
#if !defined _LIBC || (defined O_LARGEFILE && O_LARGEFILE != 0)

_IO_FILE *
_IO_fopen64 (filename, mode)
     const char *filename;
     const char *mode;
{
  return __fopen_internal (filename, mode, 0);
}

#ifdef weak_alias
weak_alias (_IO_fopen64, fopen64)
#endif

#endif
